# retronix.py
A Python library designed for interacting with the RetronixMC Public API.

This is the stable version. If you'd like to take a look at upcoming goodies that are in progress, then take a look at our `dev` branch!  *Be aware though, what you code with it might spook your program with a creepy-crawly code creature...*

### Documentation
The entirety of the Library is peppered in documentation internally, including new features that are in progress. Feel free to take a browse around the files and take a look at how stuff works to get a better understanding. Otherwise, basic guidance and detailing of the library is outlined in the Wiki section of the repository. If you need any help, feel free to get in touch with the dev team in the Discord.

### Bugs and code insects
In the event you find a bug, we ask that you open up an issue for further investigation. From there, a pull request can be made in an attempt to rectify the bug. Please follow the guidance and templates as stated in the issues tab on the proper procedure for filing an Issue. It makes your life much easier and keeps our sanity together.

Likewise for suggestions for what can be added to the library to make it more efficient or easier to use, open an issue with the suggestion label and follow the instructions from there. We'd love to hear your thoughts.
